about summary refs log tree commit diff
path: root/elf/ldconfig.c
diff options
context:
space:
mode:
authorCarlos O'Donell <carlos@redhat.com>2013-05-22 23:22:36 -0400
committerCarlos O'Donell <carlos@redhat.com>2013-05-22 23:22:36 -0400
commit13e23af76e64efc055103344bd56d553ceee8512 (patch)
tree46ea93986dadb55cdef965785508d2783342cf7d /elf/ldconfig.c
parent351fe550871f522a19b60f66aa75b96426d67f2f (diff)
downloadglibc-13e23af76e64efc055103344bd56d553ceee8512.tar.gz
glibc-13e23af76e64efc055103344bd56d553ceee8512.tar.xz
glibc-13e23af76e64efc055103344bd56d553ceee8512.zip
Update comments in ldconfig.c and dl-hwcaps.c.
In dl-hwcaps.c the comment read that rounding was done
to ElfW(Addr), but it's actually rounded to ElfW(Word).

In ldconfig.c we make each comment a sentence and
mention that the "tls" pseudo-hwcap is just for legacy
installations where TLS was optional.

---

2013-05-22  Carlos O'Donell  <carlos@redhat.com>

	* elf/ldconfig.c (is_hwcap_platform): Make comments full setences.
	(main): Mention "tls" pseudo-hwcap is legacy.
	* elf/dl-hwcaps.c (_dl_important_hwcaps): Correct rounding comment.
Diffstat (limited to 'elf/ldconfig.c')
-rw-r--r--elf/ldconfig.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/elf/ldconfig.c b/elf/ldconfig.c
index 13f262d65c..c7b9eb92fe 100644
--- a/elf/ldconfig.c
+++ b/elf/ldconfig.c
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
 {
   int hwcap_idx = _dl_string_hwcap (name);
 
   /* Is this a normal hwcap for the machine e.g. fpu?  */
   if (hwcap_idx != -1 && ((1 << hwcap_idx) & hwcap_mask))
     return 1;
 
   /* ... Or is it a platform pseudo-hwcap e.g. i686?  */
   hwcap_idx = _dl_string_platform (name);
   if (hwcap_idx != -1)
     return 1;
 
-  /* ... Or is this one of the extra pseudo-hwcaps that we map beyond
-     _DL_FIRST_EXTRA e.g. tls, or nosegneg?  */
+  /* Is this one of the extra pseudo-hwcaps that we map beyond
+     _DL_FIRST_EXTRA like "tls", or "nosegneg?"  */
   for (hwcap_idx = _DL_FIRST_EXTRA; hwcap_idx < 64; ++hwcap_idx)
     if (hwcap_extra[hwcap_idx - _DL_FIRST_EXTRA] != NULL
 	&& !strcmp (name, hwcap_extra[hwcap_idx - _DL_FIRST_EXTRA]))
@@ -1270,8 +1270,10 @@ main (int argc, char **argv)
 	  add_dir (argv[i]);
     }
 
-  /* The last entry in hwcap_extra is reserved for the "tls"
-     pseudo-hwcap which indicates support for TLS.  */
+  /* The last entry in hwcap_extra is reserved for the "tls" pseudo-hwcap which
+     indicates support for TLS.  This pseudo-hwcap is only used by old versions
+     under which TLS support was optional.  The entry is no longer needed, but
+     must remain for compatibility.  */
   hwcap_extra[63 - _DL_FIRST_EXTRA] = "tls";
 
   set_hwcap ();
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
   int hwcap_idx = _dl_string_hwcap (name);
 
-  /* Is this a normal hwcap for the machine e.g. fpu?  */
+  /* Is this a normal hwcap for the machine like "fpu?"  */
   if (hwcap_idx != -1 && ((1 << hwcap_idx) & hwcap_mask))
     return 1;
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
     return 1;
 
-  /* ... Or is it a platform pseudo-hwcap e.g. i686?  */
+  /* Is this a platform pseudo-hwcap like "i686?"  */
   hwcap_idx = _dl_string_platform (name);
   if (hwcap_idx != -1)